Game Button is an modern and unique button widget. You can use it in your project according to you need

How to use?
Add game_button: to your pubspec.yaml dependencies then run flutter pub get
Add from pub Stable
dependencies:
game_play_button:
Then import the package to use
import 'package:game_play_button/game_button.dart';
Usage
GamePlayButton(
title: 'Play Offline',
// onTap: () {},
// backColor: Colors.deepPurple,
// gradientColors: [
// Colors.purple,
// Colors.purpleAccent
// ],
// textColor: Colors.blue,
// textStokeColor: Colors.white,
// textStokeWidth: 3,
// fontWeight: FontWeight.w100,
// stokeColor: Colors.black,
// stokeWidth: 3,
)